"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CommitDenylistProtectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CommitDefinition(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class Range(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            START_COMMIT_FIELD_NUMBER: builtins.int
            END_COMMIT_FIELD_NUMBER: builtins.int
            start_commit: builtins.str
            """older commit, exclusive"""
            end_commit: builtins.str
            """newer commit, inclusive"""
            def __init__(
                self,
                *,
                start_commit: builtins.str = ...,
                end_commit: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["end_commit", b"end_commit", "start_commit", b"start_commit"]) -> None: ...

        COMMIT_FIELD_NUMBER: builtins.int
        RANGE_FIELD_NUMBER: builtins.int
        commit: builtins.str
        @property
        def range(self) -> global___CommitDenylistProtectionConfig.CommitDefinition.Range: ...
        def __init__(
            self,
            *,
            commit: builtins.str = ...,
            range: global___CommitDenylistProtectionConfig.CommitDefinition.Range | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["commit", b"commit", "commit_oneof", b"commit_oneof", "range", b"range"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["commit", b"commit", "commit_oneof", b"commit_oneof", "range", b"range"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["commit_oneof", b"commit_oneof"]) -> typing_extensions.Literal["commit", "range"] | None: ...

    REPOSITORY_FIELD_NUMBER: builtins.int
    COMMITS_FIELD_NUMBER: builtins.int
    repository: builtins.str
    @property
    def commits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommitDenylistProtectionConfig.CommitDefinition]: ...
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        commits: collections.abc.Iterable[global___CommitDenylistProtectionConfig.CommitDefinition] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commits", b"commits", "repository", b"repository"]) -> None: ...

global___CommitDenylistProtectionConfig = CommitDenylistProtectionConfig



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.object import manager_pb2 as prodvana_dot_object_dot_manager__pb2


class ObjectManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.QueryObjects = channel.unary_unary(
                '/prodvana.object.ObjectManager/QueryObjects',
                request_serializer=prodvana_dot_object_dot_manager__pb2.QueryObjectReq.SerializeToString,
                response_deserializer=prodvana_dot_object_dot_manager__pb2.QueryObjectResp.FromString,
                )
        self.GetLabels = channel.unary_unary(
                '/prodvana.object.ObjectManager/GetLabels',
                request_serializer=prodvana_dot_object_dot_manager__pb2.GetLabelsReq.SerializeToString,
                response_deserializer=prodvana_dot_object_dot_manager__pb2.GetLabelsResp.FromString,
                )


class ObjectManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def QueryObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLabels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'QueryObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryObjects,
                    request_deserializer=prodvana_dot_object_dot_manager__pb2.QueryObjectReq.FromString,
                    response_serializer=prodvana_dot_object_dot_manager__pb2.QueryObjectResp.SerializeToString,
            ),
            'GetLabels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLabels,
                    request_deserializer=prodvana_dot_object_dot_manager__pb2.GetLabelsReq.FromString,
                    response_serializer=prodvana_dot_object_dot_manager__pb2.GetLabelsResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.object.ObjectManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def QueryObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.object.ObjectManager/QueryObjects',
            prodvana_dot_object_dot_manager__pb2.QueryObjectReq.SerializeToString,
            prodvana_dot_object_dot_manager__pb2.QueryObjectResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLabels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.object.ObjectManager/GetLabels',
            prodvana_dot_object_dot_manager__pb2.GetLabelsReq.SerializeToString,
            prodvana_dot_object_dot_manager__pb2.GetLabelsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetCasBlobReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GetCasBlobReq = GetCasBlobReq

class GetCasBlobResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_FIELD_NUMBER: builtins.int
    bytes: builtins.bytes
    def __init__(
        self,
        *,
        bytes: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes", b"bytes"]) -> None: ...

global___GetCasBlobResp = GetCasBlobResp

class UploadCasBlobReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_FIELD_NUMBER: builtins.int
    bytes: builtins.bytes
    def __init__(
        self,
        *,
        bytes: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes", b"bytes"]) -> None: ...

global___UploadCasBlobReq = UploadCasBlobReq

class UploadCasBlobResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___UploadCasBlobResp = UploadCasBlobResp
